..
    This file is automatically generated. Do not make
    changes as these will be overwritten. Rather edit
    the docstrings in the source code.

``yaff`` -- YAFF - Yet another force field
##########################################




``yaff.atselect`` -- The ATSELECT language
==========================================

.. automodule:: yaff.atselect
    :members:


``yaff.log`` -- Screen logger
=============================

.. automodule:: yaff.log
    :members:


``yaff.system`` -- Representation of a molecular systems
========================================================

.. automodule:: yaff.system
    :members:


``yaff.version`` -- Do not edit this file, versioning is governed by ``git describe --tags`` and ``setup.py``.
==============================================================================================================

.. automodule:: yaff.version
    :members:
